#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""Application of easylearn
"""

def run():
    print("Initializing...")
    from eslearn.GUI.easylearn_main_run import main
    main()

if __name__ == "__main__":
    run()